# Change Log

## [1.0.1](https://github.com/dldevinc/paper-admin/tree/v1.0.1) - 2020-10-19
- Fix static files

## [1.0.0](https://github.com/dldevinc/paper-admin/tree/v1.0.0) - 2020-10-19
- Enlarge form controls
- Update `npm` deps

## [0.0.16](https://github.com/dldevinc/paper-admin/tree/v0.0.16) - 2020-09-15
- Hotfix missing static files and templates

## [0.0.15](https://github.com/dldevinc/paper-admin/tree/v0.0.15) - 2020-09-15
- Add Django 3.1 support
- Update development environment
